@@ -140,7 +140,7 @@ usage(void)
 	fprintf(stderr, "\n");
 #endif
 
-	fprintf(stderr, "see manual page lldpd(8) for more information\n");
+	fprintf(stderr, "See manual page lldpd(8) for more information\n");
 	exit(1);
 }
 
@@ -294,6 +294,7 @@ lldpd_hardware_cleanup(struct lldpd *cfg, struct lldpd_hardware *hardware)
 	free(hardware->h_lport_previous);
 	free(hardware->h_lchassis_previous_id);
 	free(hardware->h_lport_previous_id);
+	free(hardware->h_ifdescr_previous);
 	lldpd_port_cleanup(&hardware->h_lport, 1);
 	if (hardware->h_ops && hardware->h_ops->cleanup)
 		hardware->h_ops->cleanup(cfg, hardware);
@@ -302,7 +303,7 @@ lldpd_hardware_cleanup(struct lldpd *cfg, struct lldpd_hardware *hardware)
 }
 
 static void
-lldpd_display_neighbors(struct lldpd *cfg)
+lldpd_ifdescr_neighbors(struct lldpd *cfg)
 {
 	if (!cfg->g_config.c_set_ifdescr) return;
 	struct lldpd_hardware *hardware;
@@ -317,19 +318,24 @@ lldpd_display_neighbors(struct lldpd *cfg)
 			neighbor = port->p_chassis->c_name;
 		}
 		if (neighbors == 0)
-			priv_iface_description(hardware->h_ifname, "");
+			description = strdup("");
 		else if (neighbors == 1 && neighbor && *neighbor != '\0') {
-			if (asprintf(&description, "%s", neighbor) != -1) {
-				priv_iface_description(hardware->h_ifname, description);
-				free(description);
+			if (asprintf(&description, "%s", neighbor) == -1) {
+				continue;
 			}
 		} else {
 			if (asprintf(&description, "%d neighbor%s", neighbors,
-				(neighbors > 1) ? "s" : "") != -1) {
-				priv_iface_description(hardware->h_ifname, description);
-				free(description);
+				(neighbors > 1) ? "s" : "") == -1) {
+				continue;
 			}
 		}
+		if (hardware->h_ifdescr_previous == NULL ||
+		    strcmp(hardware->h_ifdescr_previous, description)) {
+			priv_iface_description(hardware->h_ifname, description);
+			free(hardware->h_ifdescr_previous);
+			hardware->h_ifdescr_previous = description;
+		} else
+			free(description);
 	}
 }
 
@@ -352,7 +358,7 @@ lldpd_count_neighbors(struct lldpd *cfg)
 	else
 		setproctitle("%d neighbor%s.", neighbors, (neighbors > 1) ? "s" : "");
 #endif
-	lldpd_display_neighbors(cfg);
+	lldpd_ifdescr_neighbors(cfg);
 }
 
 static void
@@ -759,7 +765,8 @@ static char *
 lldpd_get_lsb_release()
 {
 	static char release[1024];
-	char *const command[] = { "lsb_release", "-s", "-d", NULL };
+	char cmd[][12] = { "lsb_release", "-s", "-d" };
+	char *const command[] = { cmd[0], cmd[1], cmd[2], NULL };
 	int pid, status, devnull, count;
 	int pipefd[2];
 
@@ -952,9 +959,11 @@ lldpd_hide_ports(struct lldpd *cfg, struct lldpd_hardware *hardware, int mask)
 				memcpy(buffer + sizeof(buffer) - 4, "...", 4);
 				break;
 			}
-			if (buffer[0]) strncat(buffer, ", ", 2);
+			if (buffer[0])
+				strncat(buffer, ", ",
+				    sizeof(buffer) - strlen(buffer) - 1);
 			strncat(buffer, cfg->g_protocols[i].name,
-			    strlen(cfg->g_protocols[i].name));
+			    sizeof(buffer) - strlen(buffer) - 1);
 		}
 	}
 	log_debug("smartfilter", "%s: %s: %d visible neighbors (out of %d)",
@@ -1007,10 +1016,6 @@ lldpd_dot3_power_pd_pse(struct lldpd_hardware *hardware)
 		    hardware->h_ifname, selected_port->p_power.allocated,
 		    hardware->h_lport.p_power.allocated);
 		hardware->h_lport.p_power.allocated = selected_port->p_power.allocated;
-		hardware->h_lport.p_power.allocated_a =
-		    selected_port->p_power.allocated_a;
-		hardware->h_lport.p_power.allocated_b =
-		    selected_port->p_power.allocated_b;
 		levent_schedule_pdu(hardware);
 	}
 
@@ -1469,7 +1474,8 @@ lldpd_started_by_systemd()
 	strlcpy(su.sun_path, notifysocket, sizeof(su.sun_path));
 	if (notifysocket[0] == '@') su.sun_path[0] = 0;
 
-	struct iovec iov = { .iov_base = "READY=1", .iov_len = strlen("READY=1") };
+	char ready[] = "READY=1";
+	struct iovec iov = { .iov_base = ready, .iov_len = sizeof ready - 1 };
 	struct msghdr hdr = { .msg_name = &su,
 		.msg_namelen =
 		    offsetof(struct sockaddr_un, sun_path) + strlen(notifysocket),
@@ -1764,6 +1770,9 @@ lldpd_main(int argc, char *argv[], char *envp[])
 	}
 	log_debug("main", "lldpd " PACKAGE_VERSION " starting...");
 	version_check();
+#ifdef FUZZING_BUILD_MODE_UNSAFE_FOR_PRODUCTION
+	fatalx("main", "fuzzing enabled, unsafe for production");
+#endif
 
 	/* Grab uid and gid to use for priv sep */
 #ifdef ENABLE_PRIVSEP
