@@ -278,9 +278,7 @@ _lldp_send(struct lldpd *global, struct lldpd_hardware *hardware, u_int8_t c_id_
 	}
 	/* Power */
 	if (port->p_power.devicetype) {
-		if (!((port->p_power.type_ext != LLDP_DOT3_POWER_8023BT_OFF ?
-			      (tlv = pos, POKE_UINT16((LLDP_TLV_ORG << 9) | (0x1d))) :
-			      POKE_START_LLDP_TLV(LLDP_TLV_ORG)) &&
+		if (!((POKE_START_LLDP_TLV(LLDP_TLV_ORG)) &&
 			POKE_BYTES(dot3, sizeof(dot3)) &&
 			POKE_UINT8(LLDP_TLV_DOT3_POWER) &&
 			POKE_UINT8(((((2 - port->p_power.devicetype) % (1 << 1)) << 0) |
@@ -302,33 +300,11 @@ _lldp_send(struct lldpd *global, struct lldpd_hardware *hardware, u_int8_t c_id_
 					   1)
 				      << 6) |
 				  ((port->p_power.source % (1 << 2)) << 4) |
-				  ((port->p_power.pd_4pid % (1 << 1)) << 2) |
 				  ((port->p_power.priority % (1 << 2)) << 0))) &&
 				POKE_UINT16(port->p_power.requested) &&
 				POKE_UINT16(port->p_power.allocated)))
 				goto toobig;
 		}
-		if (port->p_power.type_ext != LLDP_DOT3_POWER_8023BT_OFF) {
-			if (!(POKE_UINT16(port->p_power.requested_a) &&
-				POKE_UINT16(port->p_power.requested_b) &&
-				POKE_UINT16(port->p_power.allocated_a) &&
-				POKE_UINT16(port->p_power.allocated_b) &&
-				POKE_UINT16(((port->p_power.pse_status << 14) |
-				    (port->p_power.pd_status << 12) |
-				    (port->p_power.pse_pairs_ext << 10) |
-				    (port->p_power.class_a << 7) |
-				    (port->p_power.class_b << 4) |
-				    (port->p_power.class_ext << 0))) &&
-				POKE_UINT8(
-				    /* Adjust by -1 to enable 0 to mean no 802.3bt
-				       support */
-				    ((port->p_power.type_ext - 1) << 1) |
-				    (port->p_power.pd_load << 0)) &&
-				POKE_UINT16(port->p_power.pse_max) &&
-				/* Send 0 for autoclass and power down requests */
-				POKE_UINT8(0) && POKE_UINT16(0) && POKE_UINT8(0)))
-				goto toobig;
-		}
 		if (!(POKE_END_LLDP_TLV)) goto toobig;
 	}
 #endif
@@ -614,7 +590,7 @@ lldp_decode(struct lldpd *cfg, char *frame, int s, struct lldpd_hardware *hardwa
 #endif
 	struct lldpd_mgmt *mgmt;
 	int af;
-	u_int8_t addr_str_length, addr_str_buffer[32];
+	u_int8_t addr_str_length, addr_str_buffer[32] = { 0 };
 	u_int8_t addr_family, addr_length, *addr_ptr, iface_subtype;
 	u_int32_t iface_number, iface;
 	int unrecognized;
@@ -688,24 +664,24 @@ lldp_decode(struct lldpd *cfg, char *frame, int s, struct lldpd_hardware *hardwa
 		case LLDP_TLV_CHASSIS_ID:
 			if (tlv_count != 1) {
 				log_warnx("lldp",
-				    "first TLV should be a chassis ID on %s, not %d",
-				    hardware->h_ifname, tlv_type);
+				    "Chassis ID TLV should be first on %s, but it is on position %d",
+				    hardware->h_ifname, tlv_count);
 				goto malformed;
 			}
 			break;
 		case LLDP_TLV_PORT_ID:
 			if (tlv_count != 2) {
 				log_warnx("lldp",
-				    "second TLV should be a port ID on %s, not %d",
-				    hardware->h_ifname, tlv_type);
+				    "Port ID TLV should be second on %s, but it is on position %d",
+				    hardware->h_ifname, tlv_count);
 				goto malformed;
 			}
 			break;
 		case LLDP_TLV_TTL:
 			if (tlv_count != 3) {
 				log_warnx("lldp",
-				    "third TLV should be a TTL on %s, not %d",
-				    hardware->h_ifname, tlv_type);
+				    "TTL TLV should be third on %s, but it is on position %d",
+				    hardware->h_ifname, tlv_count);
 				goto malformed;
 			}
 			break;
