@@ -37,34 +37,34 @@ struct lldpctl_conn_t {
 	size_t input_buffer_len;
 	size_t output_buffer_len;
 
-#define CONN_STATE_IDLE			0
-#define CONN_STATE_GET_INTERFACES_SEND	1
-#define CONN_STATE_GET_INTERFACES_RECV	2
-#define CONN_STATE_GET_PORT_SEND	3
-#define CONN_STATE_GET_PORT_RECV	4
-#define CONN_STATE_SET_PORT_SEND	5
-#define CONN_STATE_SET_PORT_RECV	6
-#define CONN_STATE_SET_WATCH_SEND	7
-#define CONN_STATE_SET_WATCH_RECV	8
-#define CONN_STATE_GET_CONFIG_SEND	9
-#define CONN_STATE_GET_CONFIG_RECV	10
-#define CONN_STATE_SET_CONFIG_SEND	11
-#define CONN_STATE_SET_CONFIG_RECV	12
-#define CONN_STATE_GET_CHASSIS_SEND	13
-#define CONN_STATE_GET_CHASSIS_RECV	14
+#define CONN_STATE_IDLE 0
+#define CONN_STATE_GET_INTERFACES_SEND 1
+#define CONN_STATE_GET_INTERFACES_RECV 2
+#define CONN_STATE_GET_PORT_SEND 3
+#define CONN_STATE_GET_PORT_RECV 4
+#define CONN_STATE_SET_PORT_SEND 5
+#define CONN_STATE_SET_PORT_RECV 6
+#define CONN_STATE_SET_WATCH_SEND 7
+#define CONN_STATE_SET_WATCH_RECV 8
+#define CONN_STATE_GET_CONFIG_SEND 9
+#define CONN_STATE_GET_CONFIG_RECV 10
+#define CONN_STATE_SET_CONFIG_SEND 11
+#define CONN_STATE_SET_CONFIG_RECV 12
+#define CONN_STATE_GET_CHASSIS_SEND 13
+#define CONN_STATE_GET_CHASSIS_RECV 14
 #define CONN_STATE_GET_DEFAULT_PORT_SEND 15
 #define CONN_STATE_GET_DEFAULT_PORT_RECV 16
-#define CONN_STATE_WATCHING		17
-#define CONN_STATE_SET_CHASSIS_SEND	18
-#define CONN_STATE_SET_CHASSIS_RECV	19
+#define CONN_STATE_WATCHING 17
+#define CONN_STATE_SET_CHASSIS_SEND 18
+#define CONN_STATE_SET_CHASSIS_RECV 19
 
-	int state;		/* Current state */
+	int state; /* Current state */
 	/* Data attached to the state. It is used to check that we are using the
 	 * same data as a previous call until the state machine goes to
 	 * CONN_STATE_IDLE. */
 	char state_data[IFNAMSIZ + 64];
 	/* Error handling */
-	lldpctl_error_t error;	/* Last error */
+	lldpctl_error_t error; /* Last error */
 
 	/* Handling notifications */
 	lldpctl_change_callback watch_cb;
@@ -75,20 +75,17 @@ struct lldpctl_conn_t {
 
 /* User data for synchronous callbacks. */
 struct lldpctl_conn_sync_t {
-	int fd;			/* File descriptor to the socket. */
+	int fd; /* File descriptor to the socket. */
 };
 
 ssize_t _lldpctl_needs(lldpctl_conn_t *lldpctl, size_t length);
-int _lldpctl_do_something(lldpctl_conn_t *conn,
-    int state_send, int state_recv, const char *state_data,
-    enum hmsg_type type,
-    void *to_send, struct marshal_info *mi_send,
-    void **to_recv, struct marshal_info *mi_recv);
+int _lldpctl_do_something(lldpctl_conn_t *conn, int state_send, int state_recv,
+    const char *state_data, enum hmsg_type type, void *to_send,
+    struct marshal_info *mi_send, void **to_recv, struct marshal_info *mi_recv);
 
 /* errors.c */
-#define SET_ERROR(conn, x)    ((conn)->error = x)
-#define RESET_ERROR(conn)     SET_ERROR((conn), LLDPCTL_NO_ERROR)
-
+#define SET_ERROR(conn, x) ((conn)->error = x)
+#define RESET_ERROR(conn) SET_ERROR((conn), LLDPCTL_NO_ERROR)
 
 /* atom.c and atom-private.c */
 typedef enum {
@@ -127,7 +124,8 @@ typedef enum {
 } atom_t;
 
 void *_lldpctl_alloc_in_atom(lldpctl_atom_t *, size_t);
-const char *_lldpctl_dump_in_atom(lldpctl_atom_t *, const uint8_t *, size_t, char, size_t);
+const char *_lldpctl_dump_in_atom(lldpctl_atom_t *, const uint8_t *, size_t, char,
+    size_t);
 
 struct atom_buffer {
 	TAILQ_ENTRY(atom_buffer) next;
@@ -141,23 +139,24 @@ struct lldpctl_atom_t {
 	TAILQ_HEAD(, atom_buffer) buffers; /* List of buffers */
 
 	/* Destructor */
-	void                 (*free)(lldpctl_atom_t *);
+	void (*free)(lldpctl_atom_t *);
 
 	/* Iterators */
 	lldpctl_atom_iter_t *(*iter)(lldpctl_atom_t *);
 	lldpctl_atom_iter_t *(*next)(lldpctl_atom_t *, lldpctl_atom_iter_t *);
-	lldpctl_atom_t      *(*value)(lldpctl_atom_t *, lldpctl_atom_iter_t *);
+	lldpctl_atom_t *(*value)(lldpctl_atom_t *, lldpctl_atom_iter_t *);
 
 	/* Getters */
 	lldpctl_atom_t *(*get)(lldpctl_atom_t *, lldpctl_key_t);
-	const char     *(*get_str)(lldpctl_atom_t *, lldpctl_key_t);
+	const char *(*get_str)(lldpctl_atom_t *, lldpctl_key_t);
 	const u_int8_t *(*get_buffer)(lldpctl_atom_t *, lldpctl_key_t, size_t *);
-	long int        (*get_int)(lldpctl_atom_t *, lldpctl_key_t);
+	long int (*get_int)(lldpctl_atom_t *, lldpctl_key_t);
 
 	/* Setters */
 	lldpctl_atom_t *(*set)(lldpctl_atom_t *, lldpctl_key_t, lldpctl_atom_t *);
 	lldpctl_atom_t *(*set_str)(lldpctl_atom_t *, lldpctl_key_t, const char *);
-	lldpctl_atom_t *(*set_buffer)(lldpctl_atom_t *, lldpctl_key_t, const u_int8_t *, size_t);
+	lldpctl_atom_t *(
+	    *set_buffer)(lldpctl_atom_t *, lldpctl_key_t, const u_int8_t *, size_t);
 	lldpctl_atom_t *(*set_int)(lldpctl_atom_t *, lldpctl_key_t, long int);
 	lldpctl_atom_t *(*create)(lldpctl_atom_t *);
 };
@@ -180,17 +179,18 @@ struct _lldpctl_atom_interface_t {
 struct _lldpctl_atom_chassis_t {
 	lldpctl_atom_t base;
 	struct lldpd_chassis *chassis;
-	struct _lldpctl_atom_port_t *parent; /* Optional: parent of this atom (owning our reference) */
-	int embedded;			     /* This atom is "embedded" (not refcounted) */
+	struct _lldpctl_atom_port_t
+	    *parent;  /* Optional: parent of this atom (owning our reference) */
+	int embedded; /* This atom is "embedded" (not refcounted) */
 };
 
 struct _lldpctl_atom_port_t {
 	lldpctl_atom_t base;
-	int local;			 /* Local or remote port? */
-	struct lldpd_hardware *hardware; /* Local port only (but optional) */
-	struct lldpd_port     *port;	 /* Local and remote */
+	int local;			     /* Local or remote port? */
+	struct lldpd_hardware *hardware;     /* Local port only (but optional) */
+	struct lldpd_port *port;	     /* Local and remote */
 	struct _lldpctl_atom_port_t *parent; /* Local port if we are a remote port */
-	lldpctl_atom_t *chassis; /* Internal atom for chassis */
+	lldpctl_atom_t *chassis;	     /* Internal atom for chassis */
 };
 
 /* Can represent any simple list holding just a reference to a port. */
@@ -262,7 +262,7 @@ struct _lldpctl_atom_med_caelement_t {
 	struct _lldpctl_atom_med_location_t *parent;
 	int type;
 	uint8_t *value;
-	size_t   len;
+	size_t len;
 };
 
 struct _lldpctl_atom_med_power_t {
@@ -291,38 +291,54 @@ struct lldpctl_atom_t *_lldpctl_new_atom(lldpctl_conn_t *conn, atom_t type, ...)
 struct atom_map {
 	int key;
 	struct atom_map *next;
-	lldpctl_map_t   map[];
+	lldpctl_map_t map[];
 };
 
 void atom_map_register(struct atom_map *map, int);
 void init_atom_map(void);
 
-#define ATOM_MAP_REGISTER(NAME, PRIO) void init_atom_map_ ## NAME() { atom_map_register(& NAME, PRIO); }
+#define ATOM_MAP_REGISTER(NAME, PRIO) \
+  void init_atom_map_##NAME(void);    \
+  void init_atom_map_##NAME(void)     \
+  {                                   \
+    atom_map_register(&NAME, PRIO);   \
+  }
 
 struct atom_builder {
-	atom_t type;	/* Atom type */
-	size_t size;	/* Size of structure to allocate */
-	int  (*init)(lldpctl_atom_t *, va_list); /* Optional additional init steps */
-	void (*free)(lldpctl_atom_t *); /* Optional deallocation steps */
+	atom_t type;				/* Atom type */
+	size_t size;				/* Size of structure to allocate */
+	int (*init)(lldpctl_atom_t *, va_list); /* Optional additional init steps */
+	void (*free)(lldpctl_atom_t *);		/* Optional deallocation steps */
 
-	lldpctl_atom_iter_t* (*iter)(lldpctl_atom_t *); /* Optional, return an iterator for this object */
-	lldpctl_atom_iter_t* (*next)(lldpctl_atom_t *,  lldpctl_atom_iter_t *); /* Return the next object for the provided iterator */
-	lldpctl_atom_t*      (*value)(lldpctl_atom_t *, lldpctl_atom_iter_t *); /* Return the current object for the provided iterator */
+	lldpctl_atom_iter_t *(*iter)(
+	    lldpctl_atom_t *); /* Optional, return an iterator for this object */
+	lldpctl_atom_iter_t *(*next)(lldpctl_atom_t *,
+	    lldpctl_atom_iter_t
+		*); /* Return the next object for the provided iterator */
+	lldpctl_atom_t *(*value)(lldpctl_atom_t *,
+	    lldpctl_atom_iter_t
+		*); /* Return the current object for the provided iterator */
 
-	lldpctl_atom_t*      (*get)(lldpctl_atom_t *,        lldpctl_key_t);
-	const char*          (*get_str)(lldpctl_atom_t *,    lldpctl_key_t);
-	const u_int8_t*      (*get_buffer)(lldpctl_atom_t *, lldpctl_key_t, size_t *);
-	long int             (*get_int)(lldpctl_atom_t *,    lldpctl_key_t);
+	lldpctl_atom_t *(*get)(lldpctl_atom_t *, lldpctl_key_t);
+	const char *(*get_str)(lldpctl_atom_t *, lldpctl_key_t);
+	const u_int8_t *(*get_buffer)(lldpctl_atom_t *, lldpctl_key_t, size_t *);
+	long int (*get_int)(lldpctl_atom_t *, lldpctl_key_t);
 
-	lldpctl_atom_t*      (*set)(lldpctl_atom_t *, lldpctl_key_t, lldpctl_atom_t *);
-	lldpctl_atom_t*      (*set_str)(lldpctl_atom_t *, lldpctl_key_t, const char *);
-	lldpctl_atom_t*      (*set_buffer)(lldpctl_atom_t *, lldpctl_key_t, const u_int8_t *, size_t);
-	lldpctl_atom_t*      (*set_int)(lldpctl_atom_t *, lldpctl_key_t, long int);
-	lldpctl_atom_t*      (*create)(lldpctl_atom_t *);
-	struct atom_builder  *nextb;
+	lldpctl_atom_t *(*set)(lldpctl_atom_t *, lldpctl_key_t, lldpctl_atom_t *);
+	lldpctl_atom_t *(*set_str)(lldpctl_atom_t *, lldpctl_key_t, const char *);
+	lldpctl_atom_t *(
+	    *set_buffer)(lldpctl_atom_t *, lldpctl_key_t, const u_int8_t *, size_t);
+	lldpctl_atom_t *(*set_int)(lldpctl_atom_t *, lldpctl_key_t, long int);
+	lldpctl_atom_t *(*create)(lldpctl_atom_t *);
+	struct atom_builder *nextb;
 };
 
 void atom_builder_register(struct atom_builder *builder, int);
 void init_atom_builder(void);
 
-#define ATOM_BUILDER_REGISTER(NAME, PRIO) void init_atom_builder_ ## NAME() { atom_builder_register(& NAME, PRIO); }
+#define ATOM_BUILDER_REGISTER(NAME, PRIO) \
+  void init_atom_builder_##NAME(void);    \
+  void init_atom_builder_##NAME(void)     \
+  {                                       \
+    atom_builder_register(&NAME, PRIO);   \
+  }
