@@ -19,25 +19,39 @@
 #include "atom.h"
 #include "../log.h"
 
-const char*
+const char *
 lldpctl_strerror(lldpctl_error_t error)
 {
 	/* No default case to let the compiler warns us if we miss an error code. */
 	switch (error) {
-	case LLDPCTL_NO_ERROR: return "No error";
-	case LLDPCTL_ERR_WOULDBLOCK: return "Requested operation would block";
-	case LLDPCTL_ERR_EOF: return "End of file reached";
-	case LLDPCTL_ERR_NOT_EXIST: return "The requested information does not exist";
-	case LLDPCTL_ERR_CANNOT_CONNECT: return "Unable to connect to lldpd daemon";
-	case LLDPCTL_ERR_INCORRECT_ATOM_TYPE: return "Provided atom is of incorrect type";
-	case LLDPCTL_ERR_SERIALIZATION: return "Error while serializing or unserializing data";
-	case LLDPCTL_ERR_INVALID_STATE: return "Other input/output operation already in progress";
-	case LLDPCTL_ERR_CANNOT_ITERATE: return "Cannot iterate on this atom";
-	case LLDPCTL_ERR_CANNOT_CREATE: return "Cannot create a new element for this atom";
-	case LLDPCTL_ERR_BAD_VALUE: return "Provided value is invalid";
-	case LLDPCTL_ERR_FATAL: return "Unexpected fatal error";
-	case LLDPCTL_ERR_NOMEM: return "Not enough memory available";
-	case LLDPCTL_ERR_CALLBACK_FAILURE: return "A failure occurred during callback processing";
+	case LLDPCTL_NO_ERROR:
+		return "No error";
+	case LLDPCTL_ERR_WOULDBLOCK:
+		return "Requested operation would block";
+	case LLDPCTL_ERR_EOF:
+		return "End of file reached";
+	case LLDPCTL_ERR_NOT_EXIST:
+		return "The requested information does not exist";
+	case LLDPCTL_ERR_CANNOT_CONNECT:
+		return "Unable to connect to lldpd daemon";
+	case LLDPCTL_ERR_INCORRECT_ATOM_TYPE:
+		return "Provided atom is of incorrect type";
+	case LLDPCTL_ERR_SERIALIZATION:
+		return "Error while serializing or unserializing data";
+	case LLDPCTL_ERR_INVALID_STATE:
+		return "Other input/output operation already in progress";
+	case LLDPCTL_ERR_CANNOT_ITERATE:
+		return "Cannot iterate on this atom";
+	case LLDPCTL_ERR_CANNOT_CREATE:
+		return "Cannot create a new element for this atom";
+	case LLDPCTL_ERR_BAD_VALUE:
+		return "Provided value is invalid";
+	case LLDPCTL_ERR_FATAL:
+		return "Unexpected fatal error";
+	case LLDPCTL_ERR_NOMEM:
+		return "Not enough memory available";
+	case LLDPCTL_ERR_CALLBACK_FAILURE:
+		return "A failure occurred during callback processing";
 	}
 	return "Unknown error code";
 }
@@ -57,5 +71,5 @@ lldpctl_log_callback(void (*cb)(int severity, const char *msg))
 void
 lldpctl_log_level(int level)
 {
-	if (level >= 1) log_level(level-1);
+	if (level >= 1) log_level(level - 1);
 }
